@@ -40,6 +40,7 @@ func NewOAuth2Cmd() (cmd *OAuth2Cmd) {
 	cmd.Command.Run = cmd.Run(&cconfig)
 
 	cmd.AddCommand(versionCmd)
+	cmd.AddCommand(docsCmd)
 
 	cmd.PersistentFlags().StringVar(&cconfig.RedirectURL, "redirect-url", "http://localhost:9876/callback", "client redirect url")
 	cmd.PersistentFlags().StringVar(&cconfig.ClientID, "client-id", "", "client identifier")
@@ -74,7 +75,8 @@ func NewOAuth2Cmd() (cmd *OAuth2Cmd) {
 	cmd.PersistentFlags().BoolVar(&cconfig.Insecure, "insecure", false, "allow insecure connections")
 	cmd.PersistentFlags().BoolVarP(&silent, "silent", "s", false, "silent mode")
 	cmd.PersistentFlags().BoolVar(&cconfig.DPoP, "dpop", false, "use DPoP")
-	cmd.PersistentFlags().StringVar(&cconfig.Claims, "claims", "", "claims parameter")
+	cmd.PersistentFlags().StringVar(&cconfig.Claims, "claims", "", "use claims")
+	cmd.PersistentFlags().StringVar(&cconfig.RAR, "rar", "", "use rich authorization request (RAR)")
 
 	return cmd
 }
